Function to estimate the type cell proportions in an unclassified cytometry data set denoted X_s by using the classification Lab_source from an other cytometry data set X_s. With this function the computation of the estimate of the class proportions is done with a descent ascent algorithm.
cytopt_desasc_r(
X_s,
X_t,
Lab_source,
theta_true = NULL,
eps = 1e-04,
n_out = 5000,
n_stoc = 10,
step_grad = 10,
monitoring = FALSE
)A list with the following elements:h_hat
a cytometry dataframe. The columns correspond to the different biological markers tracked. One line corresponds to the cytometry measurements performed on one cell. The classification of this Cytometry data set must be provided with the Lab_source parameters.
a cytometry dataframe. The columns correspond to the different biological markers tracked. One line corresponds to the cytometry measurements performed on one cell. The CytOpT algorithm targets the cell type proportion in this Cytometry data set
a vector of length n Classification of the X_s cytometry data set
If available, gold-standard proportions in the target data
set X_t derived from manual gating. It allows to assess the gap between
the estimate and the gold-standard. Default is NULL, in which case no
assessment is performed.
an float value of regularization parameter of the Wasserstein distance. Default is 1e-04.
an integer number of iterations in the outer loop. This loop corresponds to the gradient
descent algorithm to minimize the regularized Wasserstein distance between the source and
target data sets. Default is 5000.
an integer number of iterations in the inner loop. This loop corresponds to the stochastic
algorithm that approximates a maximizer of the semi-dual problem. Default is 10.
an integer number step size of the gradient descent algorithm
of the outer loop. Default is 10.
boolean indicating whether Kullback-Leibler divergence should be
monitored and store throughout the optimization iterations. Default is FALSE.