Function to estimate the type cell proportions in an unclassified cytometry data set denoted X_s by using the classification Lab_source from an other cytometry data set X_s. With this function an additional regularization parameter on the class proportions enables a faster computation of the estimator.
cytopt_minmax_r(
X_s,
X_t,
Lab_source,
theta_true = NULL,
eps = 1e-04,
lbd = 1e-04,
n_iter = 10000,
step = 5,
power = 0.99,
monitoring = FALSE
)A list with the following elements:Results_Minmax
Cytometry data set. The columns correspond to the different biological markers tracked. One line corresponds to the cytometry measurements performed on one cell. The classification of this Cytometry data set must be provided with the Lab_source parameters.
Cytometry data set. The columns correspond to the different biological markers tracked. One line corresponds to the cytometry measurements performed on one cell. The CytOpT algorithm targets the cell type proportion in this Cytometry data set.
Classification of the X_s Cytometry data set
If available, gold-standard proportions in the target data
set X_t derived from manual gating. It allows to assess the gap between
the estimate and the gold-standard. Default is NULL, in which case no
assessment is performed.
Regularization parameter of the Wasserstein distance
an float constant that multiply the step-size policy. Default is 1e-04.
an integer Constant that iterate method select. Default is 10000.
Constant that multiply the step-size policy. Default is 5.
the step size policy of the gradient ascent method is step/n^power.
Default is 0.99.
boolean indicating whether Kullback-Leibler divergence should be
monitored and store throughout the optimization iterations. Default is FALSE.